/* XPM */
static char * battery_xpm[] = {
"17 50 625 2",
"  	c None",
". 	c #CABEBE",
"+ 	c #D3C7C8",
"@ 	c #B59590",
"# 	c #B09E99",
"$ 	c #958680",
"% 	c #D4C8C0",
"& 	c #DBCDC5",
"* 	c #D8CCC4",
"= 	c #E2D5CD",
"- 	c #A19188",
"; 	c #B29E92",
"> 	c #B8A091",
", 	c #E2CFC1",
"' 	c #C19990",
") 	c #AF796F",
"! 	c #A4736A",
"~ 	c #AC8C85",
"{ 	c #9A877C",
"] 	c #D1C3B4",
"^ 	c #C1B2A3",
"/ 	c #F4E8D9",
"( 	c #AD9C8D",
"_ 	c #B0998A",
": 	c #B58D7D",
"< 	c #BD8A7A",
"[ 	c #D4A595",
"} 	c #B8775C",
"| 	c #C8805E",
"1 	c #D19C7B",
"2 	c #E6C6AB",
"3 	c #E2D3BE",
"4 	c #E8DDCB",
"5 	c #E8DFCD",
"6 	c #E7DCCB",
"7 	c #F0E3D3",
"8 	c #E8D9C8",
"9 	c #ECD7C1",
"0 	c #E2B297",
"a 	c #D09073",
"b 	c #C7815D",
"c 	c #B66B4A",
"d 	c #C06A3C",
"e 	c #CE8653",
"f 	c #E1A879",
"g 	c #DEAD7D",
"h 	c #D5A070",
"i 	c #D6A071",
"j 	c #D7A071",
"k 	c #DDA878",
"l 	c #E9B382",
"m 	c #E4AC7B",
"n 	c #D8905F",
"o 	c #C47347",
"p 	c #BB6D41",
"q 	c #B56A4D",
"r 	c #BD6434",
"s 	c #CF7F44",
"t 	c #E8A669",
"u 	c #E2A469",
"v 	c #C37D49",
"w 	c #B16835",
"x 	c #B76F3B",
"y 	c #CD8C56",
"z 	c #E5AB72",
"A 	c #E3A973",
"B 	c #D28853",
"C 	c #BA6939",
"D 	c #BA6D3F",
"E 	c #AF6852",
"F 	c #BF693B",
"G 	c #D1854A",
"H 	c #EFB070",
"I 	c #EDAD6F",
"J 	c #CB7C46",
"K 	c #B96430",
"L 	c #C16D39",
"M 	c #CF874F",
"N 	c #EAB174",
"O 	c #E6B481",
"P 	c #CA8A59",
"Q 	c #B56B3E",
"R 	c #B86F40",
"S 	c #B56850",
"T 	c #C26737",
"U 	c #D38446",
"V 	c #F1B16F",
"W 	c #EFAF71",
"X 	c #CD7E4B",
"Y 	c #BB6535",
"Z 	c #C06C3B",
"` 	c #CE8A53",
" .	c #E9B67B",
"..	c #E9B67E",
"+.	c #D28E58",
"@.	c #B96C39",
"#.	c #B96E3C",
"$.	c #B1684B",
"%.	c #C06A34",
"&.	c #D5884C",
"*.	c #F4B06E",
"=.	c #EFAB72",
"-.	c #CC7E4B",
";.	c #BC6636",
">.	c #BE6A3A",
",.	c #D28C56",
"'.	c #EBB57B",
").	c #ECB77D",
"!.	c #D58E56",
"~.	c #BD6A3A",
"{.	c #B86C3D",
"].	c #EDCDB0",
"^.	c #AD694C",
"/.	c #BD6C34",
"(.	c #D2864C",
"_.	c #F2AD6D",
":.	c #EEAA73",
"<.	c #CC7F4D",
"[.	c #B96536",
"}.	c #BC693A",
"|.	c #D18B57",
"1.	c #EBB47B",
"2.	c #EAB67D",
"3.	c #D48E56",
"4.	c #C06B3D",
"5.	c #BB6F42",
"6.	c #EDCFB4",
"7.	c #BE6D35",
"8.	c #D5894F",
"9.	c #EDA872",
"0.	c #BB6738",
"a.	c #D08B57",
"b.	c #EAB47B",
"c.	c #EAB57C",
"d.	c #D18C54",
"e.	c #C36F40",
"f.	c #BE7245",
"g.	c #ECCEB2",
"h.	c #B06D52",
"i.	c #BC6B33",
"j.	c #D6894F",
"k.	c #F5AF6F",
"l.	c #F1AD76",
"m.	c #C97C4A",
"n.	c #B76434",
"o.	c #BC6939",
"p.	c #CF8955",
"q.	c #EAB37A",
"r.	c #E6B27A",
"s.	c #CE8951",
"t.	c #C36E3F",
"u.	c #BE7144",
"v.	c #B06F54",
"w.	c #B96830",
"x.	c #D08349",
"y.	c #EFAA6A",
"z.	c #EFAA74",
"A.	c #C97D4B",
"B.	c #B86434",
"C.	c #ECB57C",
"D.	c #CD8850",
"E.	c #BD7043",
"F.	c #B16F56",
"G.	c #BA6733",
"H.	c #D1854C",
"I.	c #F0AB6C",
"J.	c #F0AB73",
"K.	c #C97D49",
"L.	c #B76332",
"M.	c #BE6B3A",
"N.	c #D18B56",
"O.	c #EDB67C",
"P.	c #E8B37D",
"Q.	c #CC8650",
"R.	c #BA683A",
"S.	c #BA7143",
"T.	c #B46E59",
"U.	c #BE693D",
"V.	c #CD884E",
"W.	c #EDAC6E",
"X.	c #EEAA6D",
"Y.	c #C77B45",
"Z.	c #B76330",
"`.	c #BF6C38",
" +	c #EDB67A",
".+	c #E5B07A",
"++	c #D08551",
"@+	c #BD6D3F",
"#+	c #B77343",
"$+	c #B47158",
"%+	c #B96938",
"&+	c #C68548",
"*+	c #E9B06C",
"=+	c #E7AB6A",
"-+	c #C97E47",
";+	c #D18B53",
">+	c #EDB679",
",+	c #E4B075",
"'+	c #CE814B",
")+	c #BC6538",
"!+	c #BB6F41",
"~+	c #E8CDAD",
"{+	c #B67057",
"]+	c #BB6736",
"^+	c #CD8347",
"/+	c #EEAE6C",
"(+	c #EBAC6B",
"_+	c #CA7E48",
":+	c #BC6935",
"<+	c #D18A52",
"[+	c #EEB77A",
"}+	c #E5B173",
"|+	c #D0834C",
"1+	c #C0683E",
"2+	c #BC6F45",
"3+	c #E8CDB0",
"4+	c #AD6F5A",
"5+	c #BA673C",
"6+	c #D5834F",
"7+	c #F3A970",
"8+	c #EDAA6E",
"9+	c #CA7E47",
"0+	c #B96732",
"a+	c #BB6935",
"b+	c #D18B52",
"c+	c #EAB375",
"d+	c #E8B377",
"e+	c #D08853",
"f+	c #B76C47",
"g+	c #B3724D",
"h+	c #E4CCB3",
"i+	c #7C5541",
"j+	c #A4623B",
"k+	c #C97E50",
"l+	c #ECA573",
"m+	c #E8A971",
"n+	c #B76431",
"o+	c #B96733",
"p+	c #CD874F",
"q+	c #E3AD70",
"r+	c #E0AA73",
"s+	c #C58355",
"t+	c #A26747",
"u+	c #855536",
"v+	c #D0BEA9",
"w+	c #291F1B",
"x+	c #2D1706",
"y+	c #55381C",
"z+	c #876848",
"A+	c #987550",
"B+	c #8B5934",
"C+	c #87542C",
"D+	c #855130",
"E+	c #92623D",
"F+	c #9D7152",
"G+	c #7E5E41",
"H+	c #533B26",
"I+	c #301E0F",
"J+	c #311F10",
"K+	c #222120",
"L+	c #130F02",
"M+	c #1A1101",
"N+	c #291B07",
"O+	c #332712",
"P+	c #31271C",
"Q+	c #564F3E",
"R+	c #867E76",
"S+	c #8D8577",
"T+	c #716763",
"U+	c #362718",
"V+	c #21190D",
"W+	c #141007",
"X+	c #261E12",
"Y+	c #201F1E",
"Z+	c #0E0A01",
"`+	c #170E02",
" @	c #2A1B0D",
".@	c #3D3025",
"+@	c #453D3B",
"@@	c #9F9991",
"#@	c #CBC4C6",
"$@	c #C8C1BE",
"%@	c #A69DA4",
"&@	c #382A1E",
"*@	c #1F160B",
"=@	c #161108",
"-@	c #271E12",
";@	c #110C04",
">@	c #180E04",
",@	c #2B1B14",
"'@	c #3D3129",
")@	c #282620",
"!@	c #919184",
"~@	c #6D6B69",
"{@	c #6E6D66",
"]@	c #9A9799",
"^@	c #34281B",
"/@	c #1F170B",
"(@	c #120E05",
"_@	c #21201E",
":@	c #110C05",
"<@	c #170D06",
"[@	c #2A1918",
"}@	c #3C2E2A",
"|@	c #504845",
"1@	c #524B43",
"2@	c #E6E0E1",
"3@	c #E8E3DF",
"4@	c #675D64",
"5@	c #37291D",
"6@	c #22190E",
"7@	c #141008",
"8@	c #1E1E1D",
"9@	c #0E0A04",
"0@	c #170D07",
"a@	c #2B1B1B",
"b@	c #3C2F2C",
"c@	c #3F3830",
"d@	c #3C3425",
"e@	c #AAA3A0",
"f@	c #BEB9B0",
"g@	c #7F7577",
"h@	c #36271C",
"i@	c #1F160C",
"j@	c #130E07",
"k@	c #271E13",
"l@	c #1F2123",
"m@	c #0C0B05",
"n@	c #191309",
"o@	c #2D211B",
"p@	c #40372F",
"q@	c #423B35",
"r@	c #9F9785",
"s@	c #B3AEAC",
"t@	c #979490",
"u@	c #6D6366",
"v@	c #342320",
"w@	c #1F140F",
"x@	c #16110C",
"y@	c #2A2117",
"z@	c #1F2224",
"A@	c #0C0B04",
"B@	c #161006",
"C@	c #261A13",
"D@	c #3A3129",
"E@	c #29231D",
"F@	c #A9A190",
"G@	c #867F7E",
"H@	c #777471",
"I@	c #61585B",
"J@	c #33221F",
"K@	c #2B2218",
"L@	c #281C15",
"M@	c #382F27",
"N@	c #4C463F",
"O@	c #574C3C",
"P@	c #CDC7C5",
"Q@	c #D5D2CF",
"R@	c #8B8185",
"S@	c #32211E",
"T@	c #1E140F",
"U@	c #15110C",
"V@	c #2C2319",
"W@	c #1E2022",
"X@	c #0C0C05",
"Y@	c #161106",
"Z@	c #413830",
"`@	c #4B443E",
" #	c #877D6D",
".#	c #D0CAC8",
"+#	c #D4D2CF",
"@#	c #92888C",
"##	c #352421",
"$#	c #1D130E",
"%#	c #140F0A",
"&#	c #140E04",
"*#	c #231811",
"=#	c #362C24",
"-#	c #37312A",
";#	c #564B3C",
">#	c #A8A09D",
",#	c #9C9A97",
"'#	c #A39A9D",
")#	c #352522",
"!#	c #201611",
"~#	c #17120D",
"{#	c #2B2219",
"]#	c #1E2020",
"^#	c #0A0A02",
"/#	c #161105",
"(#	c #261B12",
"_#	c #352B23",
":#	c #3B352D",
"<#	c #8A8173",
"[#	c #E5E1DB",
"}#	c #E6E4E3",
"|#	c #978F8F",
"1#	c #35251F",
"2#	c #231812",
"3#	c #18130D",
"4#	c #2C2418",
"5#	c #1F2220",
"6#	c #0C0C02",
"7#	c #171205",
"8#	c #261A10",
"9#	c #3D342B",
"0#	c #3D382F",
"a#	c #998F84",
"b#	c #7C756E",
"c#	c #656162",
"d#	c #4B4241",
"e#	c #372720",
"f#	c #221811",
"g#	c #18130C",
"h#	c #2F261A",
"i#	c #222523",
"j#	c #0F1005",
"k#	c #191407",
"l#	c #271D12",
"m#	c #3C332A",
"n#	c #423D33",
"o#	c #786D61",
"p#	c #EEE9E2",
"q#	c #E4E2E2",
"r#	c #7C7473",
"s#	c #21160F",
"t#	c #17130C",
"u#	c #322A1D",
"v#	c #202321",
"w#	c #0B0B02",
"x#	c #161104",
"y#	c #251A10",
"z#	c #30261D",
"A#	c #403A31",
"B#	c #5A4E43",
"C#	c #C6BFB8",
"D#	c #D6D3D4",
"E#	c #9A9290",
"F#	c #33241D",
"G#	c #20150F",
"H#	c #17120B",
"I#	c #30281B",
"J#	c #262927",
"K#	c #121208",
"L#	c #1A1507",
"M#	c #261B10",
"N#	c #322920",
"O#	c #413B31",
"P#	c #A2978B",
"Q#	c #CEC9C2",
"R#	c #7D7A7A",
"S#	c #403736",
"T#	c #34241D",
"U#	c #2F271B",
"V#	c #262827",
"W#	c #141309",
"X#	c #181205",
"Y#	c #261B11",
"Z#	c #3D332A",
"`#	c #474137",
" $	c #5C5146",
".$	c #D9D3CD",
"+$	c #DBD9D6",
"@$	c #605758",
"#$	c #34251E",
"$$	c #20160F",
"%$	c #262122",
"&$	c #120C04",
"*$	c #170F03",
"=$	c #241A0F",
"-$	c #3B3027",
";$	c #484137",
">$	c #959083",
",$	c #938C8B",
"'$	c #989288",
")$	c #999297",
"!$	c #34271F",
"~$	c #221711",
"{$	c #19140D",
"]$	c #31291C",
"^$	c #262223",
"/$	c #191105",
"($	c #33281F",
"_$	c #484237",
":$	c #8F897D",
"<$	c #534C42",
"[$	c #898087",
"}$	c #352820",
"|$	c #191004",
"1$	c #241A10",
"2$	c #32271E",
"3$	c #433C32",
"4$	c #847E71",
"5$	c #BCB6B4",
"6$	c #C2BDB3",
"7$	c #857C83",
"8$	c #241912",
"9$	c #1A150F",
"0$	c #322A1E",
"a$	c #262123",
"b$	c #140D06",
"c$	c #1B1206",
"d$	c #261C11",
"e$	c #271C12",
"f$	c #221B11",
"g$	c #A6A093",
"h$	c #C3BCBB",
"i$	c #CEC8BE",
"j$	c #9D959B",
"k$	c #33271F",
"l$	c #251A13",
"m$	c #1B1610",
"n$	c #342C20",
"o$	c #292425",
"p$	c #150F07",
"q$	c #1C1307",
"r$	c #2A2015",
"s$	c #271D13",
"t$	c #1E170D",
"u$	c #979185",
"v$	c #766D6C",
"w$	c #7A7469",
"x$	c #867D83",
"y$	c #372A22",
"z$	c #251A14",
"A$	c #352C20",
"B$	c #252324",
"C$	c #120E06",
"D$	c #1B1608",
"E$	c #2B2317",
"F$	c #271F15",
"G$	c #18120C",
"H$	c #7A7066",
"I$	c #ABA5A0",
"J$	c #B1AEAA",
"K$	c #807976",
"L$	c #372D24",
"M$	c #221C14",
"N$	c #1C1610",
"O$	c #382D22",
"P$	c #232223",
"Q$	c #0F0D05",
"R$	c #171305",
"S$	c #262013",
"T$	c #231C13",
"U$	c #17110C",
"V$	c #A89E95",
"W$	c #B6B0A9",
"X$	c #9A9794",
"Y$	c #6B645E",
"Z$	c #33291F",
"`$	c #211D14",
" %	c #382B21",
".%	c #242323",
"+%	c #18120D",
"@%	c #8C8279",
"#%	c #514841",
"$%	c #2A2724",
"%%	c #38312B",
"&%	c #332A1F",
"*%	c #1F1B12",
"=%	c #1A140E",
"-%	c #372A1F",
";%	c #1F1E1F",
">%	c #0D0B03",
",%	c #161305",
"'%	c #241E11",
")%	c #140F0B",
"!%	c #877D74",
"~%	c #C2BCB5",
"{%	c #C8C6C3",
"]%	c #867F79",
"^%	c #332920",
"/%	c #1D1910",
"(%	c #36291F",
"_%	c #1D1C1C",
":%	c #151103",
"<%	c #221C0F",
"[%	c #211B12",
"}%	c #130E09",
"|%	c #A09992",
"1%	c #8D8A87",
"2%	c #625B56",
"3%	c #2B2117",
"4%	c #1A160D",
"5%	c #1A150E",
"6%	c #232224",
"7%	c #0C0903",
"8%	c #100C01",
"9%	c #1D160A",
"0%	c #1C150C",
"a%	c #110B06",
"b%	c #7B7067",
"c%	c #453C35",
"d%	c #4C4743",
"e%	c #514943",
"f%	c #281F15",
"g%	c #1A150D",
"h%	c #18110A",
"i%	c #372A20",
"j%	c #333135",
"k%	c #090606",
"l%	c #0C0702",
"m%	c #150E05",
"n%	c #181005",
"o%	c #0E0600",
"p%	c #160E05",
"q%	c #1A1209",
"r%	c #251E14",
"s%	c #2C241A",
"t%	c #211B13",
"u%	c #17120A",
"v%	c #1B1207",
"w%	c #41342B",
"x%	c #2C2C2F",
"y%	c #090807",
"z%	c #0A0601",
"A%	c #100C02",
"B%	c #161004",
"C%	c #0D0601",
"D%	c #0E0801",
"E%	c #160F05",
"F%	c #1F180E",
"G%	c #16140A",
"H%	c #392F26",
"                                  ",
"                . +               ",
"        @ # $ % & * = - ; > ,     ",
"    ' ) ! ~ { ] ] ^ / ( _ : < [   ",
"    } | 1 2 3 4 5 6 7 8 9 0 a b   ",
"    c d e f g h i j k l m n o p   ",
"    q r s t u v w x y z A B C D   ",
"    E F G H I J K L M N O P Q R   ",
"    S T U V W X Y Z `  ...+.@.#.  ",
"    $.%.&.*.=.-.;.>.,.'.).!.~.{.].",
"    ^./.(._.:.<.[.}.|.1.2.3.4.5.6.",
"    ^.7.8._.9.<.0.~.a.b.c.d.e.f.g.",
"    h.i.j.k.l.m.n.o.p.q.r.s.t.u.  ",
"    v.w.x.y.z.A.B.}.|.C.r.D.4.E.  ",
"    F.G.H.I.J.K.L.M.N.O.P.Q.R.S.  ",
"    T.U.V.W.X.Y.Z.`.d. +.+++@+#+  ",
"    $+%+&+*+=+-+G.`.;+>+,+'+)+!+~+",
"    {+]+^+/+(+_+G.:+<+[+}+|+1+2+3+",
"    4+5+6+7+8+9+0+a+b+c+d+e+f+g+h+",
"    i+j+k+l+m+Y.n+o+p+q+r+s+t+u+v+",
"    w+x+y+z+A+B+C+D+E+F+G+H+I+J+  ",
"    K+L+M+N+O+P+Q+R+S+T+U+V+W+X+  ",
"    Y+Z+`+ @.@+@@@#@$@%@&@*@=@-@  ",
"    Y+;@>@,@'@)@!@~@{@]@^@/@(@-@  ",
"    _@:@<@[@}@|@1@2@3@4@5@6@7@X+  ",
"    8@9@0@a@b@c@d@e@f@g@h@i@j@k@  ",
"    l@m@n@o@p@q@r@s@t@u@v@w@x@y@  ",
"    z@A@B@C@D@E@F@G@H@I@J@w@x@K@  ",
"    l@A@B@L@M@N@O@P@Q@R@S@T@U@V@  ",
"    W@X@Y@C@Z@`@ #.#+#@###$#%#K@  ",
"    l@m@&#*#=#-#;#>#,#'#)#!#~#{#  ",
"    ]#^#/#(#_#:#<#[#}#|#1#2#3#4#  ",
"    5#6#7#8#9#0#a#b#c#d#e#f#g#h#  ",
"    i#j#k#l#m#n#o#p#q#r#e#s#t#u#  ",
"    v#w#x#y#z#A#B#C#D#E#F#G#H#I#  ",
"    J#K#L#M#N#O#P#Q#R#S#T#G#H#U#  ",
"    V#W#X#Y#Z#`# $.$+$@$#$$$t#U#  ",
"    %$&$*$=$-$;$>$,$'$)$!$~${$]$  ",
"    ^$&$/$l#($_$:$d#<$[$}$*#{$]$  ",
"    %$&$|$1$2$3$4$5$6$7$}$8$9$0$  ",
"    a$b$c$d$e$f$g$h$i$j$k$l$m$n$  ",
"    o$p$q$r$s$t$u$v$w$x$y$z$m$A$  ",
"    B$C$D$E$F$G$H$I$J$K$L$M$N$O$  ",
"    P$Q$R$S$T$U$V$W$X$Y$Z$`$m$ %  ",
"    .%Q$R$S$T$+%@%#%$%%%&%*%=%-%  ",
"    ;%>%,%'%T$)%!%~%{%]%^%/%9$(%  ",
"    _%Q$:%<%[%}%V$|%1%2%3%4%5% %  ",
"    6%7%8%9%0%a%b%c%d%e%f%g%h%i%  ",
"    j%k%l%m%n%o%p%q%r%s%t%u%v%w%  ",
"    x%y%z%A%B%C%D%E%F%f$*%G%9%H%  "};


/* XPM */
static char * powercord_xpm[] = {
"17 50 489 2",
"  	c None",
". 	c #B2B6C1",
"+ 	c #979BA3",
"@ 	c #979CA2",
"# 	c #91959F",
"$ 	c #9093A1",
"% 	c #A1A4AF",
"& 	c #9EA2AB",
"* 	c #979BA4",
"= 	c #878B94",
"- 	c #80848D",
"; 	c #6B6E78",
"> 	c #7C7F88",
", 	c #A8AAB4",
"' 	c #70747F",
") 	c #545861",
"! 	c #33383D",
"~ 	c #2F3438",
"{ 	c #2E333A",
"] 	c #3D414C",
"^ 	c #32373E",
"/ 	c #3A3F45",
"( 	c #3B4046",
"_ 	c #34393F",
": 	c #43484E",
"< 	c #373C41",
"[ 	c #373B3F",
"} 	c #32363C",
"| 	c #4B4E56",
"1 	c #838590",
"2 	c #484C56",
"3 	c #3F434A",
"4 	c #161B1D",
"5 	c #060B0D",
"6 	c #1C2125",
"7 	c #4F535C",
"8 	c #454A4F",
"9 	c #3F4448",
"0 	c #3B4043",
"a 	c #54595D",
"b 	c #34393D",
"c 	c #0F1315",
"d 	c #0B0F11",
"e 	c #373B40",
"f 	c #6A6C75",
"g 	c #4D5158",
"h 	c #52575B",
"i 	c #2D3234",
"j 	c #1F2525",
"k 	c #313639",
"l 	c #565A60",
"m 	c #414749",
"n 	c #1A2020",
"o 	c #101516",
"p 	c #2D3233",
"q 	c #54595A",
"r 	c #373C3D",
"s 	c #2D3131",
"t 	c #2B2F30",
"u 	c #4D5155",
"v 	c #5E6069",
"w 	c #3E4243",
"x 	c #414546",
"y 	c #585C5E",
"z 	c #5E6166",
"A 	c #52555B",
"B 	c #4A4E54",
"C 	c #4A4D52",
"D 	c #0E1116",
"E 	c #0F1217",
"F 	c #282B30",
"G 	c #505358",
"H 	c #2E3136",
"I 	c #4D5055",
"J 	c #5C5F64",
"K 	c #484C4F",
"L 	c #45494D",
"M 	c #323637",
"N 	c #25292A",
"O 	c #303436",
"P 	c #3C3F43",
"Q 	c #43464C",
"R 	c #474A51",
"S 	c #3E4046",
"T 	c #2F3237",
"U 	c #33363B",
"V 	c #43464B",
"W 	c #3F4247",
"X 	c #4C4F54",
"Y 	c #36393D",
"Z 	c #202427",
"` 	c #3A3D42",
" .	c #3D4142",
"..	c #222627",
"+.	c #1D2123",
"@.	c #212428",
"#.	c #2C2F35",
"$.	c #363940",
"%.	c #383B41",
"&.	c #383B40",
"*.	c #393C41",
"=.	c #3B3E43",
"-.	c #2C2F34",
";.	c #1B1E22",
">.	c #1F2326",
",.	c #474B4F",
"'.	c #3A3E3F",
").	c #232728",
"!.	c #1D2025",
"~.	c #282B31",
"{.	c #383B42",
"].	c #3D4046",
"^.	c #3C3F44",
"/.	c #3E4146",
"(.	c #272A2F",
"_.	c #191C20",
":.	c #1C2022",
"<.	c #292C32",
"[.	c #3D4045",
"}.	c #3C4044",
"|.	c #3A3C42",
"1.	c #2A2C32",
"2.	c #191C21",
"3.	c #1D2124",
"4.	c #464A4E",
"5.	c #464A4B",
"6.	c #161A1C",
"7.	c #1A1D22",
"8.	c #2B2E33",
"9.	c #414449",
"0.	c #373A3F",
"a.	c #24282C",
"b.	c #1D2125",
"c.	c #3D4145",
"d.	c #4E5253",
"e.	c #212526",
"f.	c #1A1E20",
"g.	c #1C1F24",
"h.	c #393C43",
"i.	c #3C4045",
"j.	c #3B4044",
"k.	c #3C4245",
"l.	c #3A4044",
"m.	c #41464A",
"n.	c #363B3F",
"o.	c #24272F",
"p.	c #191C22",
"q.	c #1C2226",
"r.	c #40474E",
"s.	c #54585A",
"t.	c #1B1F21",
"u.	c #181C20",
"v.	c #292C31",
"w.	c #3A3D44",
"x.	c #3C4146",
"y.	c #3D4246",
"z.	c #363C40",
"A.	c #23262D",
"B.	c #1B1E24",
"C.	c #1D2226",
"D.	c #3B4146",
"E.	c #83888E",
"F.	c #494D4F",
"G.	c #202425",
"H.	c #171A1F",
"I.	c #2A2D33",
"J.	c #3C4145",
"K.	c #42464A",
"L.	c #373C40",
"M.	c #24262C",
"N.	c #1E2025",
"O.	c #363A3E",
"P.	c #5A6066",
"Q.	c #33383A",
"R.	c #181C1D",
"S.	c #3E4347",
"T.	c #42474B",
"U.	c #26262C",
"V.	c #1F1F24",
"W.	c #1B1D20",
"X.	c #34373B",
"Y.	c #70757B",
"Z.	c #393D3F",
"`.	c #101415",
" +	c #171B1D",
".+	c #3D4247",
"++	c #3E4448",
"@+	c #3C4246",
"#+	c #43484C",
"$+	c #383D41",
"%+	c #26262B",
"&+	c #19191C",
"*+	c #141416",
"=+	c #343639",
"-+	c #424648",
";+	c #0B0F10",
">+	c #101416",
",+	c #16191E",
"'+	c #26292E",
")+	c #3E4148",
"!+	c #252529",
"~+	c #131215",
"{+	c #0D0D0D",
"]+	c #343538",
"^+	c #82858A",
"/+	c #3A3C40",
"(+	c #131418",
"_+	c #101116",
":+	c #14181E",
"<+	c #2A2F36",
"[+	c #373E46",
"}+	c #3C414A",
"|+	c #3C4049",
"1+	c #3D414A",
"2+	c #3E424B",
"3+	c #383C45",
"4+	c #22282F",
"5+	c #14181C",
"6+	c #17181B",
"7+	c #2B2A2E",
"8+	c #85888D",
"9+	c #37393D",
"0+	c #242428",
"a+	c #383A3E",
"b+	c #464A50",
"c+	c #444A50",
"d+	c #3D444C",
"e+	c #40444D",
"f+	c #42464F",
"g+	c #434750",
"h+	c #464A53",
"i+	c #484C55",
"j+	c #464C53",
"k+	c #2D2D30",
"l+	c #252428",
"m+	c #898C91",
"n+	c #393A3E",
"o+	c #232428",
"p+	c #484D52",
"q+	c #4F545B",
"r+	c #555C64",
"s+	c #535861",
"t+	c #51555E",
"u+	c #535760",
"v+	c #555962",
"w+	c #454B52",
"x+	c #4B4F53",
"y+	c #2F3033",
"z+	c #1F1E23",
"A+	c #8F9297",
"B+	c #3A3B3F",
"C+	c #242529",
"D+	c #3E4045",
"E+	c #50545A",
"F+	c #4C5258",
"G+	c #4C535B",
"H+	c #565B63",
"I+	c #575B64",
"J+	c #565A63",
"K+	c #585C65",
"L+	c #5A5E67",
"M+	c #595D66",
"N+	c #484E55",
"O+	c #303034",
"P+	c #222226",
"Q+	c #93969B",
"R+	c #1F2024",
"S+	c #3B3D42",
"T+	c #52565C",
"U+	c #50555C",
"V+	c #4E555D",
"W+	c #4E535B",
"X+	c #4D515A",
"Y+	c #4E525B",
"Z+	c #50545D",
"`+	c #494F56",
" @	c #2C2D30",
".@	c #212024",
"+@	c #96989E",
"@@	c #3E4044",
"#@	c #1E1F23",
"$@	c #555A61",
"%@	c #565D65",
"&@	c #575C64",
"*@	c #52565F",
"=@	c #42494F",
"-@	c #44484C",
";@	c #2B2B2E",
">@	c #201F24",
",@	c #B9BDC9",
"'@	c #44454B",
")@	c #1D1E22",
"!@	c #343539",
"~@	c #3C3D41",
"{@	c #313236",
"]@	c #37383C",
"^@	c #333438",
"/@	c #35363A",
"(@	c #36373B",
"_@	c #35363B",
":@	c #2C2D32",
"<@	c #2F3235",
"[@	c #191E22",
"}@	c #35363C",
"|@	c #222327",
"1@	c #2D2E32",
"2@	c #28282C",
"3@	c #27282C",
"4@	c #28292D",
"5@	c #292A2E",
"6@	c #2A2B2F",
"7@	c #28292E",
"8@	c #333439",
"9@	c #292B2F",
"0@	c #1E2326",
"a@	c #626367",
"b@	c #1A1B1F",
"c@	c #2E3034",
"d@	c #2C2D31",
"e@	c #2B2C31",
"f@	c #2F3034",
"g@	c #282B2E",
"h@	c #494E51",
"i@	c #C9CACE",
"j@	c #26272B",
"k@	c #2B2C30",
"l@	c #25262A",
"m@	c #3B3C41",
"n@	c #999EA1",
"o@	c #818286",
"p@	c #2E2F33",
"q@	c #34353A",
"r@	c #6A6D70",
"s@	c #5E5F63",
"t@	c #1C1D21",
"u@	c #303135",
"v@	c #6A6B6F",
"w@	c #343839",
"x@	c #272B2A",
"y@	c #181C1C",
"z@	c #25282E",
"A@	c #3B3D48",
"B@	c #3F424C",
"C@	c #3C3F48",
"D@	c #353841",
"E@	c #393C45",
"F@	c #383B44",
"G@	c #151818",
"H@	c #303131",
"I@	c #88898C",
"J@	c #3D4143",
"K@	c #343837",
"L@	c #343838",
"M@	c #262A2F",
"N@	c #3A3C46",
"O@	c #3F424B",
"P@	c #4F525A",
"Q@	c #4D5058",
"R@	c #3D4048",
"S@	c #2A2C2D",
"T@	c #2C2E2F",
"U@	c #727377",
"V@	c #404347",
"W@	c #202424",
"X@	c #363A39",
"Y@	c #34373F",
"Z@	c #40424A",
"`@	c #41444B",
" #	c #40434A",
".#	c #42454C",
"+#	c #55585F",
"@#	c #4F5153",
"##	c #1D1E21",
"$#	c #626368",
"%#	c #74777D",
"&#	c #35393A",
"*#	c #1A1E1D",
"=#	c #161A1B",
"-#	c #202328",
";#	c #21242A",
">#	c #24272C",
",#	c #25282D",
"'#	c #1B1E23",
")#	c #232429",
"!#	c #212226",
"~#	c #808186",
"{#	c #575B5E",
"]#	c #4A4E4D",
"^#	c #2F3333",
"/#	c #383C3F",
"(#	c #323539",
"_#	c #44474B",
":#	c #3F4246",
"<#	c #383B3F",
"[#	c #5A5B61",
"}#	c #83838A",
"|#	c #C1C2C7",
"1#	c #AAAEAD",
"2#	c #212525",
"3#	c #232729",
"4#	c #3C4043",
"5#	c #43474A",
"6#	c #2A2E31",
"7#	c #171B1E",
"8#	c #4E5255",
"9#	c #C0C1C5",
"0#	c #111214",
"a#	c #1C1D1F",
"b#	c #171B1C",
"c#	c #3C3F40",
"d#	c #212224",
"e#	c #1D1D1F",
"f#	c #505052",
"g#	c #C7C8CC",
"h#	c #17181A",
"i#	c #18191B",
"j#	c #0C1111",
"k#	c #1A1E1F",
"l#	c #2D3031",
"m#	c #1D1E20",
"n#	c #1F1F21",
"o#	c #565658",
"p#	c #C8CACE",
"q#	c #1A1B1D",
"r#	c #1B1C1E",
"s#	c #202526",
"t#	c #333738",
"u#	c #3E4042",
"v#	c #262729",
"w#	c #161618",
"x#	c #5E5E60",
"y#	c #161719",
"z#	c #1A1C1E",
"A#	c #282D2D",
"B#	c #2F3334",
"C#	c #16191A",
"D#	c #121315",
"E#	c #0F0F11",
"F#	c #68686A",
"G#	c #D0D1D5",
"H#	c #1C2021",
"I#	c #323436",
"J#	c #767678",
"K#	c #3C3D3F",
"L#	c #191A1C",
"M#	c #161B1C",
"N#	c #1B1F20",
"O#	c #333637",
"P#	c #151618",
"Q#	c #272729",
"R#	c #606062",
"S#	c #4B4C50",
"T#	c #25252C",
"U#	c #4E4F53",
"V#	c #3F4141",
"W#	c #232524",
"X#	c #7E7F82",
"Y#	c #F0F1F5",
"Z#	c #8B8C90",
"`#	c #23232A",
" $	c #424348",
".$	c #363838",
"+$	c #363837",
"@$	c #E7E8EA",
"#$	c #66676B",
"$$	c #1C1C23",
"%$	c #3E3F43",
"&$	c #333535",
"*$	c #303231",
"=$	c #EEEFF1",
"-$	c #2A2A31",
";$	c #292B2B",
">$	c #383A39",
",$	c #212128",
"'$	c #3D3E43",
")$	c #2D2E2F",
"!$	c #323433",
"~$	c #8C8D91",
"{$	c #2E2F36",
"]$	c #2C2E2D",
"^$	c #FAFBFD",
"/$	c #414246",
"($	c #242528",
"_$	c #343537",
":$	c #2D2E31",
"<$	c #F9FAFF",
"[$	c #4A4B4F",
"}$	c #2E2F32",
"|$	c #292A2F",
"                                  ",
"                                  ",
"    . + @ # $ % & * = - - ; > ,   ",
"  ' ) ! ~ { ] ^ / ( _ : < [ } | 1 ",
"  2 3 4 5 6 7 8 9 0 9 a b c d e f ",
"  g h i j k l m n o p q r s t u v ",
"  w x y z A B C D E F G H I J K L ",
"  M N O P Q R S F T U V W X Y Z ` ",
"   ...+.@.#.$.%.&.*.=.` ` -.;.>.,.",
"  '.).+.!.~.{.].W ^.V /.&.(._.>.,.",
"   .).:.!.<.{.&.[.[.}.[.|.1.2.3.4.",
"  5...6.7.8.$.[.^.^.*.9.0.a.b.>.c.",
"  d.e.f.g.~.h.i.j.k.l.m.n.o.p.q.r.",
"  s...t.u.v.w.x.j.y.j.m.z.A.B.C.D.",
"E.F.G.+.H.I.w.i.J.y.}.K.L.M.N.3.O.",
"P.Q.R.+.2.8.{.J.J.S.J.T.L.U.V.W.X.",
"Y.Z.`. +_.F w..+y.++@+#+$+%+&+*+=+",
"E.-+;+>+,+'+)+9 y.++@+#+$+!+~+{+]+",
"^+/+(+_+:+<+[+}+|+1+2+|+3+4+5+6+7+",
"8+9+0+a+b+c+d+e+f+g+h+i+h+j+4.k+l+",
"m+n+o+a+p+q+r+s+t+t+u+v+v+w+x+y+z+",
"A+B+C+D+E+F+G+H+I+J+K+L+M+N+,.O+P+",
"Q+B+R+S+T+U+V+W+X+Y+Z+t+Y+`+L  @.@",
"+@@@#@a+T+$@%@&@J+J+J+*@X+=@-@;@>@",
",@'@)@!@~@{@]@^@^@/@(@!@^@_@:@<@[@",
"  }@|@1@/@{@1@2@3@3@4@5@6@7@8@9@0@",
"  a@b@1@!@c@6@d@5@5@5@5@6@e@f@g@h@",
"  i@]@1@f@j@^@6@k@d@k@4@l@R+m@g@n@",
"    o@R+/@C+5@5@d@1@p@k@4@q@_@r@  ",
"    s@|@t@]@1@d@d@1@p@u@{@_@C+v@  ",
"    w@x@y@z@A@B@C@D@E@F@F@G@H@I@  ",
"    J@K@L@M@N@O@P@Q@P@P@R@S@T@U@  ",
"    V@W@X@a.Y@Z@`@ #.#.#+#@###$#  ",
"    %#&#*#=#-#;#>#,#(.'#'+)#!#~#  ",
"      {#]#^#/#(#_#:#<#X.:#[#}#|#  ",
"        1#2#3#>.4#5#6#7#8#        ",
"        9#0#a#b#'.c#d#e#f#        ",
"        g#h#i#j#k#l#m#n#o#        ",
"        p#q#r#s#t#u#v#w#x#        ",
"        g#y#z#A#B#C#D#E#F#        ",
"        G#m#0#H#w@I#m#*+J#        ",
"          K#L#M#N#O#P#Q#R#        ",
"            S#T#U#V#W#X#          ",
"          Y#Z#`# $.$+$@$          ",
"            #$$$%$&$*$=$          ",
"            ~@-$~@;$>$            ",
"            ]@,$'$)$!$            ",
"            ~${$q@)$]$^$          ",
"            /$($_$:$d@<$          ",
"            [$v#I#}$|$            "};

/* XPM */
static char * gauge_xpm[] = {
"19 50 3 1",
" 	c none",
".	c #000000000000",
"X	c #FFFF00000000",
"     ..........    ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX..      ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX....    ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX..      ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX....    ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX..      ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX....    ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX..      ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX.       ",
"     .XXXXX..      ",
"    .XXXXXXXX.     ",
"   .XXXXXXXXXX.    ",
"   .XXXXXXXXXX.    ",
"   .XXXXXXXXXX.    ",
"   .XXXXXXXXXX.    ",
"   .XXXXXXXXXX.    ",
"    .XXXXXXXX.     ",
"     ..XXXX..      ",
"       ....        "};


/* XPM */
static char * powercharges_xpm[] = {
"17 50 83 1",
" 	c none",
".	c #90909898A0A0",
"X	c #909090909898",
"o	c #90909090A0A0",
"O	c #A0A0A0A0A8A8",
"+	c #9898A0A0A8A8",
"@	c #808088889090",
"#	c #808080808888",
"$	c #686868687878",
"%	c #787878788888",
"&	c #A8A8A8A8B0B0",
"*	c #707070707878",
"=	c #505058586060",
"-	c #303038383838",
";	c #282830303838",
":	c #383840404848",
">	c #303030303838",
",	c #383838384040",
"<	c #383840404040",
"1	c #404048484848",
"2	c #303038384040",
"3	c #484848485050",
"4	c #808080809090",
"5	c #101018181818",
"6	c #000008080808",
"7	c #181820202020",
"8	c #484850505858",
"9	c #505058585858",
"0	c #080810101010",
"q	c #080808081010",
"w	c #686868687070",
"e	c #505050505858",
"r	c #282830303030",
"t	c #404040404848",
"y	c #FFFFFFFF0000",
"u	c #282828283030",
"i	c #484850505050",
"p	c #585860606868",
"a	c #404040404040",
"s	c #585858585858",
"d	c #585860606060",
"f	c #585858586060",
"g	c #484848484848",
"h	c #303030303030",
"j	c #202028282828",
"k	c #404048485050",
"l	c #202020202020",
"z	c #202020202828",
"x	c #181818182020",
"c	c #383838383838",
"v	c #808088888888",
"b	c #181818181818",
"n	c #101010101010",
"m	c #080808080808",
"M	c #101010101818",
"N	c #282828282828",
"B	c #404040405050",
"V	c #888888889090",
"C	c #505050506060",
"Z	c #888890909090",
"A	c #909098989898",
"S	c #202018182020",
"D	c #B8B8B8B8C8C8",
"F	c #606060606060",
"G	c #C8C8C8C8C8C8",
"H	c #98989898A0A0",
"J	c #808080808080",
"K	c #686868686868",
"L	c #383838384848",
"P	c #888888888888",
"I	c #303038383030",
"U	c #707070707070",
"Y	c #606060606868",
"T	c #C0C0C0C0C0C0",
"R	c #A8A8A8A8A8A8",
"E	c #505050505050",
"W	c #C0C0C8C8C8C8",
"Q	c #D0D0D0D0D0D0",
"!	c #787878788080",
"~	c #F0F0F0F0F0F0",
"^	c #E0E0E8E8E8E8",
"/	c #E8E8E8E8F0F0",
"(	c #F8F8F8F8F8F8",
"                 ",
"                 ",
"   ..XoO+.@##$%& ",
" *=-;;:>,<-12->34",
" 3:56781:<:9-0q2w",
" 8er7>=t7yr9-ruip",
" <asde330yuerifg1",
" hjh,tk<uy>t<3-l,",
" <l7zu2,y,,,,ux71",
" cz77u,<y,t<,jx71",
" <z77u,y<<yyyux71",
" 1l5xu2y,y,y-j77<",
" ilxxuyyy<<y-zx7t",
" 9lxxu,<<<yt2zx7<",
"vgl75u,<<<yt2z77-",
"d-b7xu,<<y<t2zxx>",
"*cn5xu,<<y<1,zbn>",
"vtqn5j::<y<1,znm>",
"#,Mn5u2:::::,j55N",
"v-zckk:ttBk3kk1uz",
"Vczc38==eeC==k3rx",
"Zcz<e88===fff31hl",
"Xc7,ee8888ee831ul",
"A<xce======e811NS",
"Dtx>,h->>>>>>>urx",
" >lu>huNjjNNNN>N7",
" Fbu>rNuNNNNNurN3",
" G-urz>NuuuNz7,NH",
"  J7>zNNuuuuN>>w ",
"  flx-uuuuuhh>zK ",
"  -jbjL:L2,,,5hP ",
"  <I-j,:8888:NNU ",
"  al-j>ttttt9ixY ",
"  *-b5zzzjjxjzlJ ",
"   9grc>t<c><f#T ",
"    Rlz7<tu5i    ",
"    Tnb5c,lbE    ",
"    W5b0brxxe    ",
"    Gbbl><zMf    ",
"    WMbNr5nqK    ",
"    Qxn7-hxn*    ",
"     cb5xhMzF    ",
"      3z3<l!     ",
"     ~Vzt-I^     ",
"      Yx,hh/     ",
"      ,u,Nc      ",
"      -z,Nh      ",
"      Vu>NN(     ",
"      azhuu(     ",
"      gzhuN      "};
